@@ -7,7 +7,7 @@
 module Main (main) where
 
 import Control.Monad
-import Data.List
+import Data.List ( (\\) )
 import DynFlags
 import Language.Haskell.Extension
 
@@ -36,10 +36,11 @@ check title expected got
 
 -- See Note [Adding a language extension] in compiler/main/DynFlags.hs.
 expectedGhcOnlyExtensions :: [String]
-expectedGhcOnlyExtensions = ["RelaxedLayout",
-                             "AlternativeLayoutRule",
-                             "AlternativeLayoutRuleTransitional"
-                            ]
+expectedGhcOnlyExtensions =
+    [ "RelaxedLayout"
+    , "AlternativeLayoutRule"
+    , "AlternativeLayoutRuleTransitional"
+    ]
 
 expectedCabalOnlyExtensions :: [String]
 expectedCabalOnlyExtensions = ["Generics",
